@@ -7,6 +7,7 @@ from .wps import AttackWPS
 from .pmkid import AttackPMKID
 from ..config import Configuration
 from ..util.color import Color
+from ..model.target import WPSState
 
 
 class AttackAll(object):
@@ -25,7 +26,7 @@ class AttackAll(object):
         targets_remaining = len(targets)
         for index, target in enumerate(targets, start=1):
             if Configuration.attack_max != 0 and index > Configuration.attack_max:
-                print("Attacked %d targets, stopping because of the --first flag" % Configuration.attack_max)
+                print(("Attacked %d targets, stopping because of the --first flag" % Configuration.attack_max))
                 break
             attacked_targets += 1
             targets_remaining -= 1
@@ -66,7 +67,7 @@ class AttackAll(object):
 
             # WPS
             if not Configuration.use_pmkid_only:
-                if target.wps is not False and AttackWPS.can_attack_wps():
+                if target.wps is WPSState.UNLOCKED and AttackWPS.can_attack_wps():
                     # Pixie-Dust
                     if Configuration.wps_pixie:
                         attacks.append(AttackWPS(target, pixie_dust=True))
@@ -157,7 +158,7 @@ class AttackAll(object):
 
         from ..util.input import raw_input
         Color.p(prompt)
-        answer = raw_input().lower()
+        answer = input().lower()
 
         if answer.startswith('s'):
             return None  # Skip
