@@ -11,7 +11,7 @@ class Tshark(Dependency):
     ''' Wrapper for Tshark program. '''
     dependency_required = False
     dependency_name = 'tshark'
-    dependency_url = 'apt-get install wireshark'
+    dependency_url = 'apt install wireshark'
 
     def __init__(self):
         pass
@@ -36,12 +36,14 @@ class Tshark(Dependency):
         for line in output.split('\n'):
             src, dst, index, total = Tshark._extract_src_dst_index_total(line)
 
-            if src is None: continue  # Skip
+            if src is None:
+                continue  # Skip
 
             index = int(index)
             total = int(total)
 
-            if total != 4: continue  # Handshake X of 5? X of 3? Skip it.
+            if total != 4:
+                continue  # Handshake X of 5? X of 3? Skip it.
 
             # Identify the client and target MAC addresses
             if index % 2 == 1:
@@ -95,7 +97,7 @@ class Tshark(Dependency):
 
         bssids = set()
         # Check if we have all 4 messages for the handshake between the same MACs
-        for (target_client, num) in target_client_msg_nums.items():
+        for (target_client, num) in list(target_client_msg_nums.items()):
             if num == 4:
                 # We got a handshake!
                 this_bssid = target_client.split(',')[0]
@@ -224,8 +226,8 @@ if __name__ == '__main__':
     # Should update 'wps' field of a target
     Tshark.check_for_wps_and_update_targets(test_file, targets)
 
-    print('Target(BSSID={}).wps = {} (Expected: 1)'.format(
-        targets[0].bssid, targets[0].wps))
+    print(('Target(BSSID={}).wps = {} (Expected: 1)'.format(
+        targets[0].bssid, targets[0].wps)))
     assert targets[0].wps == WPSState.UNLOCKED
 
-    print(Tshark.bssids_with_handshakes(test_file, bssid=target_bssid))
+    print((Tshark.bssids_with_handshakes(test_file, bssid=target_bssid)))
